pub struct GoogleLogger<M: LogMapper> { /* private fields */ }Expand description
A logger that writes entries to Google Cloud Logging using the entries.write API.
Implementations
Sourceimpl<M: LogMapper> GoogleLogger<M>
impl<M: LogMapper> GoogleLogger<M>
Sourcepub fn new(
log_label: Arc<str>,
credential_bytes: impl AsRef<[u8]>,
mapper: M,
) -> Result<GoogleLogger<M>, LoggerError>
pub fn new( log_label: Arc<str>, credential_bytes: impl AsRef<[u8]>, mapper: M, ) -> Result<GoogleLogger<M>, LoggerError>
Creates a new GoogleLogger with the given log label, service account credentials, and log mapper.
Sourcepub async fn write_logs(
&mut self,
log_entry: Vec<Value>,
) -> Result<(), LoggerError>
pub async fn write_logs( &mut self, log_entry: Vec<Value>, ) -> Result<(), LoggerError>
Sends a batch of log entries to Google Cloud Logging.
Each entry is passed through the configured LogMapper before being sent.
pub fn context(&self) -> LogContext